AlarmMethods class

Implementers

Constructors

AlarmMethods()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addAlarm(DateTime time, {String? uid, Map<String, dynamic>? payload, Duration? screenWakeDuration}) → Future<AlarmItem>
deleteAlarm(int id) → Future<void>
deleteAlarmsByPayload(Map<String, dynamic> payload) → Future<void>
deleteAlarmsByTime(DateTime dateTime) → Future<void>
deleteAlarmsByUid(String uid) → Future<void>
deleteAllAlarms() → Future<void>
getAlarm(int id) → Future<AlarmItem>
getAlarmByPayload(Map<String, dynamic> payload) → Future<List<AlarmItem>>
getAlarmByTime(DateTime time) → Future<List<AlarmItem>>
getAlarmByUid(String uid) → Future<List<AlarmItem>>
getAllAlarms() → Future<List<AlarmItem>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onForegroundAlarmEventHandler(OnForegroundAlarmEvent alarmEvent) → void
requestPermission() → Future<bool>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited